@@ -1,4 +1,4 @@
-from typing import Any, NamedTuple, Optional, Sequence, TypeVar, overload
+from typing import Any, Callable, NamedTuple, Optional, Sequence, TypeVar, overload
 
 
 class Param(NamedTuple):
@@ -6,6 +6,7 @@ class Param(NamedTuple):
     required: bool
     positional: bool
     default: Optional[object]
+    type: Optional[Callable[[str], object]]
     help: Optional[str]
 
 
@@ -15,10 +16,10 @@ T = TypeVar("T")
 @overload
 def param(
     *flags: str,
-    required: bool = False,
-    positional: bool = False,
+    required: bool = ...,
+    positional: bool = ...,
     default: T,
-    help: Optional[str] = None,
+    help: Optional[str] = ...,
 ) -> T:
     ...
 
@@ -26,10 +27,32 @@ def param(
 @overload
 def param(
     *flags: str,
-    required: bool = False,
-    positional: bool = False,
-    default: Optional[object] = None,
-    help: Optional[str] = None,
+    required: bool = ...,
+    positional: bool = ...,
+    type: Callable[[str], T],
+    help: Optional[str] = ...,
+) -> T:
+    ...
+
+
+@overload
+def param(
+    *flags: str,
+    required: bool = ...,
+    positional: bool = ...,
+    default: T,
+    type: Callable[[str], T],
+    help: Optional[str] = ...,
+) -> T:
+    ...
+
+
+@overload
+def param(
+    *flags: str,
+    required: bool = ...,
+    positional: bool = ...,
+    help: Optional[str] = ...,
 ) -> Any:
     ...
 
@@ -39,6 +62,7 @@ def param(
     required: bool = False,
     positional: bool = False,
     default: Optional[object] = None,
+    type: Optional[Callable[[str], object]] = None,
     help: Optional[str] = None,
 ) -> Any:
     return Param(
@@ -46,5 +70,6 @@ def param(
         required=required,
         positional=positional,
         default=default,
+        type=type,
         help=help,
     )
